using System.Windows.Forms;
using System.Data;
using System.Data.SqlClient;    // Namespace for working with SQL Server databases

class PlanetsForm : Form
{
    // Declare some objects we'll be talking to from different methods

    DataGridView dg;
    SqlDataAdapter da;

    public PlanetsForm()
    // This is the "constructor" method for the PlanetsForm class
    {
        // Set the window title
        this.Text = "Two-way Database Grid Binding";

        // Determine the physical path to the PLANETS sample database
        string dbLocation = 
            System.IO.Path.GetFullPath("../../../database/SqlServer/planets.mdf");

        // Prepare to connect to the SQL Server database
        string connectionString =
            @"data source=.\SQLEXPRESS;" +
            "User Instance=true;Integrated Security=SSPI;AttachDBFilename="
            + @dbLocation;

        /* Add a "Save" button to the form */

        Button btnSave = new Button();
        btnSave.Text = "Save";
        btnSave.Click += new System.EventHandler(BtnSave_Click);
        btnSave.Dock = DockStyle.Top;
        this.Controls.Add(btnSave);

        /* Add a DataGridView to the form */

        dg = new DataGridView();
        dg.Width = this.Width;
        dg.Height = 250;
        dg.Dock = DockStyle.Fill;
        this.Controls.Add(dg);

        /* Instantiate a few objects that are smart with data and use them 
           together to "bind" the DataGridView to the back-end data we want */

        // DataAdapter will act as bridge between  database and in-memory DataTable
        da = new SqlDataAdapter("SELECT * FROM PLANET", connectionString);

        // CommandBuilder will handle UPDATE and INSERT automatically
        SqlCommandBuilder cb = new SqlCommandBuilder(da);

        // DataTable will keep track, in memory, of changes
        DataTable dt = new DataTable();

        // Fill the DataTable with the data now
        da.Fill(dt);

        // Link the DataTable to the DataGridView now
        dg.DataSource = dt;

    }

    static void Main()
    {
        // Start a new instance of a forms application, using our class above
        Application.Run(new PlanetsForm());
    }

    private void BtnSave_Click(object sender, System.EventArgs e)
    {
        // Since the save button was clicked, update the database with
        // any changes made to the DataGridView's underlying source, which
        // in this case is a DataTable.

        da.Update((DataTable)dg.DataSource);
        MessageBox.Show
            ("Data has been saved", "For your information", MessageBoxButtons.OK);
    }
}