using System;
using System.Windows.Forms;
using System.Drawing;
using System.Xml;       // Namespace for working with XML generally
using System.Xml.XPath; // Namespace for working with XML "paths"

class XmlRetriever : Form
{
    ComboBox comboBox1;
    Button button1;
    ListBox listBox1;
    RichTextBox richTextBox1;
    XmlDocument xmlDoc;

    // Constructor method for our class
    public XmlRetriever()
    {
        // Set the window title and height

        this.Text = "XML Retrieval";
        this.Size = new Size(400, 400);

        // Load an XML file from disk into an XmlDocument object in memory

        xmlDoc = new XmlDocument();
        xmlDoc.Load("../../data/earthData.xml");

        // Prepare a large text box to show the data in

        richTextBox1 = new RichTextBox();
        richTextBox1.Dock = DockStyle.Top;
        richTextBox1.AcceptsTab = true;
        richTextBox1.Height = 180;
        richTextBox1.ReadOnly = true;
        richTextBox1.BackColor = Color.Silver;

        // Put the XML into the text box and add the textbox to the form

        richTextBox1.Text = xmlDoc.OuterXml;
        this.Controls.Add(richTextBox1);

        // Add a combobox control that allows the user to either type
        // an Xpath expression or to choose an existing one. Add some
        // as examples to help the user learn to write XPath expressions.
        // (A combo box is a combination of a textbox and a listbox)

        comboBox1 = new ComboBox();
        comboBox1.Location = new Point(0, 200);
        comboBox1.Width = 300;
        comboBox1.Items.Add("//Earth/Continent");
        comboBox1.Items.Add("//Earth/Continent/Country");
        comboBox1.Items.Add("//Earth/Continent/Country[@capital='Nairobi']");
        comboBox1.SelectedIndex = 0;
        this.Controls.Add(comboBox1);

        // Add a button that will cause the matching items to be displayed

        button1 = new Button();
        button1.Text = "Get data";
        button1.Location = new Point(310, 200);
        button1.Click += new EventHandler(Button1_Click);
        this.Controls.Add(button1);

        // Add a listbox to display the items returned

        listBox1 = new ListBox();
        listBox1.Dock = DockStyle.Bottom;
        listBox1.Location = new Point(10, 10);
        this.Controls.Add(listBox1);
    }

    static void Main()
    {
        // Start a new instance of a forms application, using our class above
        Application.Run( new XmlRetriever() );
    }

    // An eventhandler that will run when the button is clicked
    void Button1_Click(object sender, EventArgs e)
    {
        XmlNodeList xmlNodes;
        XmlNode xmlElement;
        string elementValue;

        // Use a try-catch structure to catch and handle any XPath errors 
        // neatly instead of just letting the program crash

        try
        {
            // From the XML document, select the items specified by the
            // XPath query chosen in the combobox

            xmlNodes = xmlDoc.SelectNodes(comboBox1.Text);

            listBox1.Items.Clear();

            // Loop through all the macthing items that were found, 
            // adding each item to the listbox
            for (int i = 0; i < xmlNodes.Count; i++)
            {
                xmlElement = xmlNodes[i];
                if (xmlElement.HasChildNodes)
                {
                    elementValue = xmlElement.FirstChild.Value.Trim();
                    listBox1.Items.Add(elementValue);
                }
            }
        }
        catch (XPathException ex)
        {
            // If an XPath error was encountered, tell the user neatly and carry on
            MessageBox.Show
                (
                    "No matching data was found. Try another xPath expression.", 
                    "Error Encountered. " + ex.Message
                );
        }
    }
}